@@ -6,12 +6,12 @@ Mojolicious::Plugin::OAuth2::Server - Easier implementation of an OAuth2
 Authorization Server / Resource Server with Mojolicious
 
 =for html
-<a href='https://travis-ci.org/G3S/mojolicious-plugin-oauth2-server?branch=master'><img src='https://travis-ci.org/G3S/mojolicious-plugin-oauth2-server.svg?branch=master' alt='Build Status' /></a>
-<a href='https://coveralls.io/r/G3S/mojolicious-plugin-oauth2-server?branch=master'><img src='https://coveralls.io/repos/G3S/mojolicious-plugin-oauth2-server/badge.png?branch=master' alt='Coverage Status' /></a>
+<a href='https://travis-ci.org/Humanstate/mojolicious-plugin-oauth2-server?branch=master'><img src='https://travis-ci.org/Humanstate/mojolicious-plugin-oauth2-server.svg?branch=master' alt='Build Status' /></a>
+<a href='https://coveralls.io/r/Humanstate/mojolicious-plugin-oauth2-server?branch=master'><img src='https://coveralls.io/repos/Humanstate/mojolicious-plugin-oauth2-server/badge.png?branch=master' alt='Coverage Status' /></a>
 
 =head1 VERSION
 
-0.25
+0.26
 
 =head1 SYNOPSIS
 
@@ -100,7 +100,7 @@ use Mojo::URL;
 use Net::OAuth2::AuthorizationServer;
 use Carp qw/ croak /;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 my $args_as_hash;
 my ( $AuthCodeGrant,$PasswordGrant,$Grant );
@@ -450,7 +450,7 @@ This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. If you would like to contribute documentation
 or file a bug report then please raise an issue / pull request:
 
-    https://github.com/G3S/mojolicious-plugin-oauth2-server
+    https://github.com/Humanstate/mojolicious-plugin-oauth2-server
 
 =cut
 
